@@ -747,12 +747,12 @@ static GtkActionEntry entries[] = {
 	
 	{ "CopyKeyName", GTK_STOCK_COPY, N_("_Copy Key Name"), "<control>C", N_("Copy the name of the selected key"), 
 	  G_CALLBACK (gconf_editor_window_copy_key_name) },
-	{ "Find", GTK_STOCK_FIND, N_("Find..."), "<control>F", N_("Find patterns in keys and values"), 
+	{ "Find", GTK_STOCK_FIND, N_("_Find..."), "<control>F", N_("Find patterns in keys and values"), 
 	  G_CALLBACK (gconf_editor_window_search) },
-	{ "RecentKeys", NULL, N_("List Recent keys"), "<control>R", N_("Show recently modified keys"), 
+	{ "RecentKeys", NULL, N_("_List Recent Keys"), "<control>R", N_("Show recently modified keys"), 
 	  G_CALLBACK (gconf_editor_show_recent_keys) },
 
-	{ "AddBookmark", NULL, N_("_Add Bookmark"), NULL, N_("Add a bookmark to the selected directory"), 
+	{ "AddBookmark", GTK_STOCK_ADD, N_("_Add Bookmark"), NULL, N_("Add a bookmark to the selected directory"), 
 	  G_CALLBACK (gconf_editor_window_add_bookmark) },
 	{ "EditBookmarks", NULL, N_("_Edit Bookmarks"), NULL, N_("Edit the bookmarks"), 
 	G_CALLBACK (gconf_editor_window_edit_bookmarks) },
@@ -1109,13 +1109,15 @@ gconf_editor_window_update_list_selection (GtkTreeSelection *selection, GConfEdi
 
 	if (schema == NULL) {
 		GConfValue *value = gconf_client_get (window->client, path, NULL);
-		if (value->type == GCONF_VALUE_SCHEMA) {
-			gtk_widget_hide (window->no_schema_label);
+		if (value != NULL) {
+			if (value->type == GCONF_VALUE_SCHEMA) {
+				gtk_widget_hide (window->no_schema_label);
+			}
+			else {
+				gtk_widget_show (window->no_schema_label);
+			}
+			gconf_value_free (value);
 		}
-		else {
-			gtk_widget_show (window->no_schema_label);
-		}
-		gconf_value_free (value);
 	}
 	else {
 		gtk_widget_hide (window->no_schema_label);
